@@ -1,6 +1,5 @@
 import os
 from argparse import Namespace
-from typing import Optional
 
 from luscious_dl.album import Album, search_albums, print_search
 from luscious_dl.command_line import command_line
@@ -11,11 +10,12 @@ from luscious_dl.user import User
 from luscious_dl.utils import info
 
 
-def albums_download(albums_ids: list[int], downloader: Downloader) -> None:
+def albums_download(albums_ids: list[int], downloader: Downloader, foldername_format='%t') -> None:
   """
   Start albums download process.
   :param albums_ids: list of album ids
   :param downloader: Downloder object
+  :param foldername_format: album folder name format
   """
   for id_ in albums_ids:
     album = Album(id_)
@@ -23,18 +23,19 @@ def albums_download(albums_ids: list[int], downloader: Downloader) -> None:
       if album.fetch_info():
         album.show()
         album.fetch_pictures()
-        album.download(downloader)
+        album.download(downloader, foldername_format)
       else:
         raise Exception('Album Information not found.')
     except Exception as e:
       logger.critical(f'Album: {id_} Error: {e}')
 
 
-def users_download(users_ids: list[int], downloader: Downloader) -> None:
+def users_download(users_ids: list[int], downloader: Downloader, foldername_format='%t') -> None:
   """
   Start users download process.
   :param users_ids: list of user ids
   :param downloader: Downloder object
+  :param foldername_format: album folder name format
   """
   for id_ in users_ids:
     user = User(id_)
@@ -42,7 +43,7 @@ def users_download(users_ids: list[int], downloader: Downloader) -> None:
       if user.fetch_info():
         user.fetch_albums()
         user.show()
-        albums_download(user.albums_ids, downloader)
+        albums_download(user.albums_ids, downloader, foldername_format)
       else:
         raise Exception('User Information not found.')
     except Exception as e:
@@ -52,6 +53,8 @@ def users_download(users_ids: list[int], downloader: Downloader) -> None:
 def normalize_args(args: Namespace) -> Namespace:
   if args.threads <= 0:
     args.threads = os.cpu_count()
+    if not args.threads:
+      args.threads = 1
   if args.page <= 0:
     args.page = 1
   if args.max_pages <= 0:
@@ -84,11 +87,11 @@ def start(args: Namespace = None) -> None:
   downloader = Downloader(args.directory, args.threads, args.retries, args.timeout, args.delay)
 
   if args.albums_ids:
-    albums_download(args.albums_ids, downloader)
+    albums_download(args.albums_ids, downloader, args.foldername_format)
   elif args.users_ids:
-    users_download(args.users_ids, downloader)
+    users_download(args.users_ids, downloader, args.foldername_format)
   elif args.keyword:
-    result = search_albums(search_query=args.keyword, page=args.page, max_pages=args.max_pages)
+    result = search_albums(args.keyword, args.sorting, args.page, args.max_pages)
     print_search(result)
     if args.search_download:
       for album in result:
